==> js-data-structs-1.0.4.tgz: package/README.md <==
# js-data-structs
A small data structures library for JavaScript, also includes some algorithms like DFS and BFS.

## Installing
### npm package
`npm i js-data-structs`

### CDN
`https://cdn.jsdelivr.net/npm/js-data-structs/DataStructures.js`

## Implemented Data structures/ Algos-
- Trees
    - Binary Trees
    - Binary Search Trees
- Stack
- Queue
- Priority Queue
- Graph 
    - BFS
    - DFS
- Trie
- Power set (recursion method)

## Usage
- [Trees](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L63)
- [Binary Trees](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L129)
- [Binary Search Trees](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L215)
- [Stack](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L253)
- [Queue](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L288)
- [Priority Queue](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L331)
- [Graph](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L439)
- [Trie](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L498)
- [Power Set](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L528)

Better documentation will be ready soon

# Future features
- [ ] Minified version

- [ ] Heaps
    - [ ] Heapsort
    - [ ] Min heap
    - [ ] Max heap
- [ ] Suffix trees
- [ ] Sets
- [ ] More Graph algorithms

==> js-data-structs-1.0.5.tgz: package/README.md <==

<h1 align="center">
JS data structs<br>

</h1>
<h3 align="center">

<img src ="https://img.shields.io/npm/dt/js-data-structs.svg?style=flat-square">
<img src ="https://img.shields.io/npm/v/js-data-structs.svg?style=flat-square">
</h3>


A small data structures library for JavaScript, also includes some algorithms like DFS and BFS.

## Installing
### npm package
`npm i js-data-structs`

### CDN
`https://cdn.jsdelivr.net/npm/js-data-structs/DataStructures.js`

## Implemented Data structures/ Algos-
- Trees
    - Binary Trees
    - Binary Search Trees
- Linked List
- Stack
- Queue
- Priority Queue
- Graph 
    - BFS
    - DFS
- Trie
- Power set (recursion method)

## Usage
- [Trees](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L63)
- [Binary Trees](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L129)
- [Binary Search Trees](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L215)
- [Linked List](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L633)
- [Stack](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L253)
- [Queue](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L288)
- [Priority Queue](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L331)
- [Graph](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L439)
- [Trie](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L498)
- [Power Set](https://github.com/Aveek-Saha/js-data-structs/blob/master/DataStructures.js#L528)

Better documentation will be ready soon

# Future features
- [x] Minified version

- [x] Linked List
    - [ ] Circular Linked List
    - [ ] Doubly Linked List
- [ ] Heaps
    - [ ] Heapsort
    - [ ] Min heap
    - [ ] Max heap
- [ ] Suffix trees
- [ ] Sets
- [ ] More Graph algorithms
